# Generated by Django 5.0.6 on 2024-07-02 01:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0006_alter_customeradditionalfields_field_values'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customergroupchangelog',
            name='old_group',
            field=models.ForeignKey(blank=True, help_text='Old group', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='old_group', to='artd_customer.customergroup', verbose_name='Old group'),
        ),
    ]



# Generated by Django 5.0.6 on 2024-07-23 01:35

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0008_customer_partner'),
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customergroup',
            name='partner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='artd_partner.partner'),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ArtdCustomerConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    verbose_name = _("ArtD Customer")
    name = "artd_customer"

    def ready(self):
        from artd_customer import signals  # noqa: F401



from django.contrib import admin
from artd_customer.models import (
    Customer,
    Tag,
    CustomerTag,
    CustomerAddress,
    CustomerAdditionalFields,
    CustomerGroup,
    CustomerGroupChangeLog,
)
from django_json_widget.widgets import JSONEditorWidget
from django.db import models
from django.utils.translation import gettext_lazy as _
from django import forms


class CustomerTagInline(admin.StackedInline):
    model = CustomerTag
    extra = 0
    fields = (
        "tag",
        "status",
    )


class CustomerAddressInline(admin.StackedInline):
    model = CustomerAddress
    extra = 0
    fields = (
        "city",
        "phone",
        "address",
        "status",
    )


@admin.register(Tag)
class TagAdmin(admin.ModelAdmin):
    list_display = [
        "description",
        "id",
        "partner",
        "status",
    ]
    search_fields = [
        "id",
        "description",
        "partner__name",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    list_filter = [
        "status",
    ]
    fieldsets = (
        (
            _("Tag Information"),
            {
                "fields": (
                    "description",
                    "partner",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(CustomerGroup)
class CustomerGroupAdmin(admin.ModelAdmin):
    list_display = [
        "group_name",
        "partner",
        "id",
        "group_code",
        "status",
    ]
    search_fields = [
        "group_name",
        "id",
        "group_code",
        "status",
        "created_at",
        "updated_at",
    ]
    list_filter = [
        "status",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Group Information"),
            {
                "fields": (
                    "partner",
                    "group_name",
                    "group_code",
                    "group_description",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(CustomerTag)
class CustomerTagAdmin(admin.ModelAdmin):
    list_display = [
        "customer",
        "id",
        "tag",
        "status",
    ]
    search_fields = [
        "customer__name",
        "customer__last_name",
        "customer__email",
        "customer__phone",
        "tag__description",
        "id",
    ]
    list_filter = [
        "status",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Customer Tag Information"),
            {
                "fields": (
                    "customer",
                    "tag",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(CustomerAddress)
class CustomerAddressAdmin(admin.ModelAdmin):
    list_display = [
        "customer",
        "id",
        "city",
        "phone",
        "address",
        "status",
    ]
    search_fields = [
        "id",
        "customer__email",
        "customer__phone",
        "customer__name",
        "customer__last_name",
        "city__name",
        "phone",
        "address",
    ]
    list_filter = [
        "status",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Customer Address Information"),
            {
                "fields": (
                    "customer",
                    "city",
                    "phone",
                    "address",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Other Information"),
            {
                "fields": ("other_data",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(CustomerAdditionalFields)
class CustomerAdditionalFieldsAdmin(admin.ModelAdmin):
    search_fields = [
        "id",
        "partner__name",
        "name",
        "field_type",
        "label",
        "required",
    ]
    list_display = [
        "name",
        "id",
        "field_type",
        "label",
        "partner",
        "required",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    list_filter = [
        "status",
        "field_type",
        "required",
    ]
    fieldsets = (
        (
            _("Additional Field Information"),
            {
                "fields": (
                    "partner",
                    "name",
                    "field_type",
                    "label",
                    "required",
                ),
            },
        ),
        (
            _("Field Values"),
            {
                "fields": ("field_values",),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(CustomerGroupChangeLog)
class CustomerGroupChangeLogAdmin(admin.ModelAdmin):
    search_fields = [
        "id",
        "customer",
        "old_group",
        "new_group",
    ]
    list_display = [
        "customer",
        "old_group",
        "new_group",
        "status",
        "created_at",
        "updated_at",
    ]
    readonly_fields = [
        "customer",
        "old_group",
        "new_group",
        "status",
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Customer Group Change Log Information"),
            {
                "fields": (
                    "customer",
                    "old_group",
                    "new_group",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(Customer)
class CustomerAdmin(admin.ModelAdmin):
    search_fields = [
        "id",
        "name",
        "last_name",
        "phone",
        "email",
        "partner__name",
    ]
    list_display = [
        "id",
        "name",
        "last_name",
        "phone",
        "email",
        "status",
    ]
    list_filter = [
        "status",
        "customer_group",
    ]
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Customer Information"),
            {
                "fields": (
                    "partner",
                    "name",
                    "last_name",
                    "phone",
                    "email",
                    "birth_date",
                    "document",
                    "city",
                    "customer_group",
                ),
            },
        ),
        (
            _("Other Information"),
            {
                "fields": ("other_data",),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    inlines = [
        CustomerTagInline,
        CustomerAddressInline,
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }



from django.core.management.base import BaseCommand
from artd_customer.models import CustomerGroup
from artd_partner.models import Partner

CUSTOMER_GROUPS = [
    {
        "group_code": "new",
        "group_name": "New customers",
        "description": "New customers",
    },
    {
        "group_code": "wholesale",
        "group_name": "Wholesale customers",
        "description": "Wholesale customers",
    },
    {
        "group_code": "vip",
        "group_name": "VIP customers",
        "description": "VIP customers",
    },
]


class Command(BaseCommand):
    help = "Create the base customer groups."

    def add_arguments(self, parser):
        parser.add_argument(
            "--partner_slug",
            type=str,
            help="Slug of the partner",
            default=None,
        )

    def handle(self, *args, **options):
        partner_slug = options["partner_slug"]
        for group in CUSTOMER_GROUPS:
            if (
                CustomerGroup.objects.filter(group_code=group["group_code"]).count()
                == 0
            ):
                customer_group = CustomerGroup.objects.create(
                    group_code=group["group_code"],
                    group_name=group["group_name"],
                    group_description=group["description"],
                )
                self.stdout.write(
                    self.style.WARNING(f'Customer group {group["group_code"]} created')
                )
            else:
                customer_group = CustomerGroup.objects.filter(
                    group_code=group["group_code"]
                ).update(
                    group_name=group["group_name"],
                    group_description=group["description"],
                )
                self.stdout.write(
                    self.style.ERROR(f'Customer group {group["group_code"]} updated')
                )
            if partner_slug:
                partner = Partner.objects.filter(partner_slug=partner_slug).last()
                customer_group.partner = partner
                customer_group.save()



# Generated by Django 5.0.1 on 2024-03-09 17:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0005_alter_customeradditionalfields_field_values"),
    ]

    operations = [
        migrations.AlterField(
            model_name="customeradditionalfields",
            name="field_values",
            field=models.JSONField(
                blank=True,
                default=list,
                help_text='If the field is of type list, you must place the values \u200b\u200bseparated by commas inside the container [] and each value inside quotes, for example ["Dog","Cat"]',
                null=True,
                verbose_name="Field values",
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-03-09 17:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0003_customer_external_id_customer_source_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="customeradditionalfields",
            name="field_values",
            field=models.JSONField(
                blank=True,
                default=list,
                help_text="If the field is of type list, you must place the values \u200b\u200bseparated by commas",
                null=True,
                verbose_name="Field values",
            ),
        ),
        migrations.AlterField(
            model_name="customeradditionalfields",
            name="field_type",
            field=models.CharField(
                choices=[
                    ("number", "Number"),
                    ("date", "Date"),
                    ("email", "Email"),
                    ("password", "Password"),
                    ("text", "Text"),
                    ("list", "List"),
                ],
                help_text="Field type",
                max_length=10,
                verbose_name="Field type",
            ),
        ),
    ]
